---
icon: lucide/heart
---

## Funding

Development of Raytrax has been partially supported by the German Federal Ministry of Research, Technology and Space (BMFTR) under the grant **FPP-MC** (13F1001B).

![](assets/bmftr.svg){ width="350" }


## Open Source

Raytrax is standing on the shoulders of giants. We are grateful to the open source community for providing the tools and libraries that made this project possible. In particular, we would like to thank the developers of the [JAX](https://github.com/google/jax), [diffrax](https://github.com/patrick-kidger/diffrax), and [interpax](https://github.com/f0uriest/interpax) libraries, which are the backbone of Raytrax's computational capabilities.